@@ -15,7 +15,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-dnd.c 6952 2007-03-11 19:42:02Z chpe $
  */
 
 #include "config.h"
@@ -23,8 +22,7 @@
 #include "ephy-dnd.h"
 #include "ephy-node.h"
 
-#include <gtk/gtkselection.h>
-#include <gtk/gtktreeview.h>
+#include <gtk/gtk.h>
 #include <string.h>
 
 /* Encode a "_NETSCAPE_URL_" selection.
@@ -83,7 +81,7 @@ ephy_dnd_drag_data_get (GtkWidget *widget,
         GString *result = NULL;
 	GdkAtom target;
 
-	target = selection_data->target;
+	target = gtk_selection_data_get_target (selection_data);
 
 	if (target == gdk_atom_intern (EPHY_DND_URI_LIST_TYPE, FALSE) ||
 	    target == gdk_atom_intern (EPHY_DND_TEXT_TYPE, FALSE))
@@ -108,7 +106,7 @@ ephy_dnd_drag_data_get (GtkWidget *widget,
 	}
 
         gtk_selection_data_set (selection_data,
-                                selection_data->target,
+                                target,
                                 8, (const guchar *) result->str, result->len);
 
 	g_string_free (result, TRUE);
